Improve this Doc

# Error: $interpolate:dupvalue
Duplicate choice in plural/select

    The choice “{0}” is specified more than once. Duplicate key is at line {1}, column {2} in text “{3}”

## Description

You have repeated a match selection for your plural or select MessageFormat extension in your interpolation expression. The different choices have to be unique.

For more information about the MessageFormat syntax in interpolation expressions, please refer to MessageFormat extensions section at Angular i18n MessageFormat